# With UsrMove (F-17, RHEL-7 onwards), we want the library installed to %%{_libdir} rather than /%%{_lib}
%global UsrMove %([ 0%{?fedora} -gt 16 -o 0%{?rhel} -gt 6 ] && echo 1 || echo 0)

# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Library for error values used by GnuPG components
Name:		libgpg-error
Version:	1.39
Release:	1.0.cf.%{__distinit}%{__distvers}
URL:		https://www.gnupg.org/related_software/libgpg-error/
Source0:	ftp://ftp.gnupg.org/gcrypt/libgpg-error/libgpg-error-%{version}.tar.bz2
Source1:	ftp://ftp.gnupg.org/gcrypt/libgpg-error/libgpg-error-%{version}.tar.bz2.sig
Patch1:		libgpg-error-1.29-multilib.patch
License:	LGPLv2+
BuildRequires:	coreutils
BuildRequires:	gawk
BuildRequires:	gcc
BuildRequires:	gettext
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 20)
BuildRequires:	/bin/hostname
%else
BuildRequires:	hostname
%endif
BuildRequires:	make
BuildRequires:	pkgconfig
BuildRequires:	sed
%if %{UsrMove}
Conflicts:	filesystem < 3
%else
BuildRequires:	symlinks
BuildRequires:	texinfo
%endif

%description
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon and possibly more in the future.

%package devel
Summary:	Development files for the libgpg-error package
Requires:	%{name} = %{version}-%{release}
Requires:	pkgconfig
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
Requires(post):	/sbin/install-info
Requires(preun):/sbin/install-info
%endif

%description devel
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon and possibly more in the future. This package
contains files necessary to develop applications using libgpg-error.

%prep
%setup -q

# Do not conflict on header file between architectures (#1180857)
%patch1 -p1 -b .multlib

# The config script already suppresses the -L if it's /usr/lib, so cheat and
# set it to a value that we know will be suppressed.
sed -i -e 's|^libdir=@libdir@$|libdir=@exec_prefix@/lib|g' src/gpg-error-config.in
sed -i -e '/--variable=host/d' src/gpg-error-config-test.sh.in

%build
%configure --disable-static --disable-rpath --disable-languages

# Kill bogus RPATHs
sed -i 's|^sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} INSTALL="install -p"

# Remove files we don't want packaged
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_infodir}/dir

%find_lang %{name}

# Relocate the shared libraries to /%%{_lib}
%if ! %{UsrMove}
mkdir -p %{buildroot}/%{_lib}
for shlib in %{buildroot}%{_libdir}/*.so*; do
	if [ -L ${shlib} ]; then
		shlib_target=$(basename $(readlink ${shlib}))
		rm ${shlib}
		[ $(basename ${shlib}) = libgpg-error.so ] && ln -s %{buildroot}/%{_lib}/${shlib_target} ${shlib}
	else
		mv ${shlib} %{buildroot}/%{_lib}/
	fi
done
symlinks -cs %{buildroot}%{_libdir}

# Add the soname symlink back in
/sbin/ldconfig -n %{buildroot}/%{_lib}/
%endif

%check
# Work around ancient pkg-config that doesn't like the test
%if "%{?rhel}" == "6" || "%{?fedora}" == "13"
echo "exit 0" > src/gpg-error-config-test.sh
%endif
make check

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig scriptlets replaced by RPM File Triggers from Fedora 28
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post devel
[ -f %{_infodir}/gpgrt.info.gz ] && \
	/sbin/install-info %{_infodir}/gpgrt.info.gz %{_infodir}/dir
exit 0

%preun devel
if [ $1 = 0 -a -f %{_infodir}/gpgrt.info.gz ]; then
	/sbin/install-info --delete %{_infodir}/gpgrt.info.gz %{_infodir}/dir
fi
exit 0
%endif

%files -f %{name}.lang
%if 0%{?_licensedir:1}
%license COPYING COPYING.LIB
%else
%doc COPYING COPYING.LIB
%endif
%doc AUTHORS README NEWS ChangeLog
%{_bindir}/gpg-error
%{_datadir}/libgpg-error/
%if %{UsrMove}
%{_libdir}/libgpg-error.so.0
%{_libdir}/libgpg-error.so.0.*
%else
/%{_lib}/libgpg-error.so.0
/%{_lib}/libgpg-error.so.0.*
%endif

%files devel
%{_bindir}/gpg-error-config
%{_bindir}/gpgrt-config
%{_bindir}/yat2m
%{_libdir}/libgpg-error.so
%{_libdir}/pkgconfig/gpg-error.pc
%{_includedir}/gpg-error.h
%{_includedir}/gpgrt.h
%{_datadir}/aclocal/gpg-error.m4
%{_datadir}/aclocal/gpgrt.m4
%{_infodir}/gpgrt.info*
%{_mandir}/man1/gpgrt-config.*

%changelog
* Thu Dec  3 2020 Paul Howarth <paul@city-fan.org> - 1.39-1.0.cf
- Update to 1.39 (https://dev.gnupg.org/T5031)
  - New option parser with features to implement system wide configuration
    files
  - New functions to build file names
  - New function to help reallocating arrays
  - Protect gpgrt_inc_errorcount against counter overflow
  - Improve cross-building for new platforms (https://dev.gnupg.org/T4774)
  - Support 64-bit big-endian MIPS architecture (https://dev.gnupg.org/T4952)
  - Support static link for Windows with -lws2_32 (https://dev.gnupg.org/T4623)
  - On Windows gpgrt_fopen, gpgrt_chdir, and gpgrt_mkdir now handle UTF-8 names
    (https://dev.gnupg.org/T4083)
  - Make timeout of gpgrt_poll work correctly on Windows if no file descriptors
    are active
  - New function gpgrt_fcancel as alternative to gpgrt_close; this function
    avoids flushing out buffered data and also tries to delete a newly-created
    file
  - Changes to ease cross-building (https://dev.gnupg.org/T4973)
  - "gpg-error --lib-version" works again
  - New symbols (in 1.38): gpgrt_fnameconcat, gpgrt_absfnameconcat,
    gpgrt_reallocarray, gpgrt_set_confdir, gpgrt_argparser, ARGPARSE_FLAG_SYSm
    ARGPARSE_FLAG_USER, ARGPARSE_FLAG_VERBOSE, ARGPARSE_FLAG_USERVERS,
    ARGPARSE_FLAG_WITHATTR, ARGPARSE_NO_CONFFILE, ARGPARSE_CONFFILE,
    ARGPARSE_OPT_CONFFILE, ARGPARSE_ATTR_FORCE, ARGPARSE_ATTR_IGNORE,
    ARGPARSE_TYPE_MASK, ARGPARSE_PERMISSION_ERROR, ARGPARSE_INVALID_META,
    ARGPARSE_UNKNOWN_META, ARGPARSE_UNEXPECTED_META, ARGPARSE_conffile,
    ARGPARSE_noconffile, ARGPARSE_verbatim, ARGPARSE_header,
    GPGRT_CONFDIR_USER, GPGRT_CONFDIR_SYS
  - New symbols (in 1.39): gpgrt_fcancel

* Wed Jul 29 2020 Paul Howarth <paul@city-fan.org> - 1.37-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Feb 28 2020 Paul Howarth <paul@city-fan.org> - 1.37-1.0.cf
- Update to 1.37 (https://dev.gnupg.org/T4772)
  - Fix a build problem when using Gawk 5.0 (https://dev.gnupg.org/T4459)
  - Fix Bourne shell incompatibilities on Solaris (https://dev.gnupg.org/T4574)
  - Improve cross-compiling support (https://dev.gnupg.org/T4643)
  - On Windows, strerror_s is now used to emulate strerror_r
    (https://dev.gnupg.org/T4539)
  - New error codes to map SQLite primary error codes
  - Now uses poll(2) instead of select(2) in gpgrt_poll if possible
  - Fix a bug in gpgrt_close (https://dev.gnupg.org/T4698)
  - Fix build problem under Cygwin (https://dev.gnupg.org/T4474)
  - Fix a few minor portability bugs
  - New symbols: GPG_ERR_NO_KEYBOXD, GPG_ERR_KEYBOXD, GPG_ERR_NO_SERVICE,
    GPG_ERR_SERVICE, GPG_ERR_SQL_OK, GPG_ERR_SQL_ERROR, GPG_ERR_SQL_INTERNAL,
    GPG_ERR_SQL_PERM, GPG_ERR_SQL_ABORT, GPG_ERR_SQL_BUSY, GPG_ERR_SQL_LOCKED,
    GPG_ERR_SQL_NOMEM, GPG_ERR_SQL_READONLY, GPG_ERR_SQL_INTERRUPT,
    GPG_ERR_SQL_IOERR, GPG_ERR_SQL_CORRUPT, GPG_ERR_SQL_NOTFOUND,
    GPG_ERR_SQL_FULL, GPG_ERR_SQL_CANTOPEN, GPG_ERR_SQL_PROTOCOL,
    GPG_ERR_SQL_EMPTY, GPG_ERR_SQL_SCHEMA, GPG_ERR_SQL_TOOBIG,
    GPG_ERR_SQL_CONSTRAINT, GPG_ERR_SQL_MISMATCH, GPG_ERR_SQL_MISUSE,
    GPG_ERR_SQL_NOLFS, GPG_ERR_SQL_AUTH, GPG_ERR_SQL_FORMAT, GPG_ERR_SQL_RANGE,
    GPG_ERR_SQL_NOTADB, GPG_ERR_SQL_NOTICE, GPG_ERR_SQL_WARNING,
    GPG_ERR_SQL_ROW, GPG_ERR_SQL_DONE
- Ignore difference in --host output in gpgrt-config

* Thu Jan 30 2020 Paul Howarth <paul@city-fan.org> - 1.36-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Aug 19 2019 Paul Howarth <paul@city-fan.org> - 1.36-2.0.cf
- Update to 1.36 (https://dev.gnupg.org/T4413)
  - Support for riscv32
  - Support armv7a-unknown-linux-gnueabihf
  - Increased estream buffer sizes for Windows
  - New API to allow emergency clean-up after internal fatal errors
  - Two new error codes to better support PIV cards
  - Minor bug and portability fixes
    - https://dev.gnupg.org/T4286
    - https://dev.gnupg.org/T4298
  - New symbols (in 1.34): gpgrt_abort, gpgrt_add_emergency_cleanup
  - New symbols (in 1.36): GPG_ERR_NO_AUTH, GPG_ERR_BAD_AUTH

* Thu Jul 25 2019 Paul Howarth <paul@city-fan.org> - 1.33-3.0.cf
- Fix for compatibility with gawk 5 (https://dev.gnupg.org/T4459)

* Tue Feb  5 2019 Paul Howarth <paul@city-fan.org> - 1.33-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sun Jan 13 2019 Paul Howarth <paul@city-fan.org> - 1.33-1.0.cf
- Update to 1.33
  - Release-info: https://dev.gnupg.org/T4205
  - Fixes a problem with gpgrt_fflush and gpgrt_fopencookie
    (https://dev.gnupg.org/T4069)
  - Fixes a problem with the C11 header stdnoreturn.h
    (https://dev.gnupg.org/T4002)
  - The yat2m tool can now also be build on Windows
  - Updates translations for Spanish, Russian and Ukrainian
  - New unified config script gpgrt-config which can now be used by all GnuPG
    related packages
  - Support for ARC and arm64ilp32
  - The log functions now sanitize strings printed with the "%%s" format
    specifier; all control characters are C-escaped in the output, so users of
    that function may want to remove their own escaping to avoid doubling of
    backslashes
  - New fprintf style function to apply a custom filter for string arguments
  - New function to compare version strings
  - New symbols relative to the 1.28 release: gpgrt_cmp_version,
    gpgrt_string_filter_t, gpgrt_fprintf_sf, gpgrt_fprintf_sf_unlocked,
    gpgrt_ftruncate, gpgrt_w32_override_locale
- Don't run install-info scriptlets from Fedora 28 onwards

* Mon Jul 16 2018 Paul Howarth <paul@city-fan.org> - 1.31-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun Jun 17 2018 Paul Howarth <paul@city-fan.org> - 1.31-1.0.cf
- Update to 1.31
  - Fix a hang on Windows when using gpgrt_poll under nPth
  - Build fix for Solaris (https://dev.gnupg.org/T3869)
  - Fix another problem with gpgrt_poll under Windows
    (https://dev.gnupg.org/T3937)
  - New translation for Spanish

* Fri Apr 13 2018 Paul Howarth <paul@city-fan.org> - 1.29-1.0.cf
- Update to 1.29
  - The formerly internal yat2m tool is now installed
  - The new files gpgrt.m4 and gpgrt-config are now installed; they can be used
    instead of gpg-error.m4 and gpg-error-config
  - New logging functions similar to those used by GnuPG
  - New option parser and associated functions similar to the one used by GnuPG
  - New helper functions for platform abstraction
  - New Base-64 encoder
  - New symbols (in 1.28): gpgrt_get_errorcount, gpgrt_inc_errorcount,
    gpgrt_log_set_sink, gpgrt_log_set_socket_dir_cb,
    gpgrt_log_set_pid_suffix_cb, gpgrt_log_set_prefix, gpgrt_log_get_prefix,
    gpgrt_log_test_fd, gpgrt_log_get_fd, gpgrt_log_get_stream, gpgrt_log,
    gpgrt_logv, gpgrt_logv_prefix, gpgrt_log_string, gpgrt_log_info,
    gpgrt_log_error, gpgrt_log_fatal, gpgrt_log_bug, gpgrt_log_debug,
    gpgrt_log_debug_string, gpgrt_log_printf, gpgrt_log_flush,
    gpgrt_log_printhex, gpgrt_log_clock, gpgrt_assert, _gpgrt_log_assert,
    GPGRT_LOGLVL_BEGIN, GPGRT_LOGLVL_CONT, GPGRT_LOGLVL_INFO,
    GPGRT_LOGLVL_WARN, GPGRT_LOGLVL_ERROR, GPGRT_LOGLVL_FATAL,
    GPGRT_LOGLVL_BUG, GPGRT_LOGLVL_DEBUG, gpgrt_realloc, gpgrt_malloc,
    gpgrt_calloc, gpgrt_strdup, gpgrt_strconcat, gpgrt_w32_reg_query_string,
    gpgrt_getenv, gpgrt_setenv, gpgrt_mkdir, gpgrt_chdir, gpgrt_getcwd
  - New symbols (in 1.29): gpgrt_argparse, gpgrt_usage, gpgrt_strusage,
    gpgrt_set_strusage, gpgrt_set_usage_outfnc, gpgrt_set_fixed_string_mapper,
    GPGRT_ENABLE_ARGPARSE_MACROS, gpgrt_b64enc_start, gpgrt_b64enc_write,
    gpgrt_b64enc_finish

* Fri Feb  9 2018 Paul Howarth <paul@city-fan.org> - 1.27-5.0.cf
- ldconfig scriptlets replaced by RPM File Triggers from Fedora 28
- Use forward-looking conditionals

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 1.27-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Paul Howarth <paul@city-fan.org> - 1.27-2.0.cf
- Update to 1.27
  - New option --desc for gpg-error
  - Added a Base64 decoder
  - Added support for the sh3 architecture
  - Added header gpgrt.h as an alias for gpg-error.h
  - Fixed macro GPGRT_GCC_VERSION
  - Fixed a race in non-blocking I/O on Windows
  - New symbols (in 1.26): GPG_ERR_UNKNOWN_FLAG, GPG_ERR_INV_ORDER,
    GPG_ERR_ALREADY_FETCHED, GPG_ERR_TRY_LATER, GPG_ERR_SYSTEM_BUG,
    GPG_ERR_DNS_UNKNOWN, GPG_ERR_DNS_SECTION, GPG_ERR_DNS_ADDRESS,
    GPG_ERR_DNS_NO_QUERY, GPG_ERR_DNS_NO_ANSWER, GPG_ERR_DNS_CLOSED,
    GPG_ERR_DNS_VERIFY, GPG_ERR_DNS_TIMEOUT
  - New symbols (in 1.27): gpgrt_b64dec_start, gpgrt_b64dec_proc,
    gpgrt_b64dec_finish, GPG_ERR_WRONG_NAME
  - New type: gpgrt_b64state_t
  - New header: gpgrt.h
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Feb 10 2017 Paul Howarth <paul@city-fan.org> - 1.25-2.0.cf
- Update to 1.25
  - New interface gpgrt_get_syscall_clamp to allow libraries to make use of
    libgpg-error's system call wrapper functions
  - gpgrt_poll now works under Windows
  - Fixed bug in the locking code when used with the nPth threading library
  - Added support for {i686,x86_64}-apple-darwin
  - Added new error codes
  - New symbols: gpgrt_get_syscall_clamp, GPG_ERR_ENGINE_TOO_OLD,
    GPG_ERR_WINDOW_TOO_SMALL, GPG_ERR_WINDOW_TOO_LARGE, GPG_ERR_MISSING_ENVVAR,
    GPG_ERR_USER_ID_EXISTS, GPG_ERR_NAME_EXISTS, GPG_ERR_DUP_NAME,
    GPG_ERR_TOO_OLD, GPG_ERR_TOO_YOUNG

* Sat Jul 16 2016 Paul Howarth <paul@city-fan.org> - 1.24-1.0.cf
- Update to 1.24
  - New functions and macros to provide iconv(3) on Windows
  - Support for LeakSanitizer with the gpgrt_annotate_leaked_object inline
    function
  - Fixes an assertion failure due to es_flush on read/write streams
  - Fixes a bug with a too short memory limit in es_fopenmen
  - Cross-build support for powerpc-unknown-linux-gnuspe and
    tilegx-unknown-linux-gnu architectures
  - Fixes a bug in es_fclose_snatch when used used after es_fseek
  - Fixes building without thread support
  - New configure option --disable-tests
  - Interface changes:
    - New inline function gpgrt_annotate_leaked_object
    - Other new symbols:
      GPGRT_ENABLE_W32_ICONV_MACROS,
      GPG_ERR_DB_CORRUPTED, GPG_ERR_SUBKEYS_EXP_OR_REV,
      gpgrt_w32_iconv_open, gpgrt_w32_iconv_close, gpgrt_w32_iconv

* Sun Mar 20 2016 Paul Howarth <paul@city-fan.org> - 1.21-3.0.cf
- Drop explicit /sbin/ldconfig scriptlet deps (#1319144)

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 1.21-2.0.cf
- Update to 1.21
  - New functions gpgrt_poll and gpgrt_set_nonblock; for now only pipes and
    sockets on Unix are supported
  - Fixes gettext output encoding problems on Windows
  - New interfaces: gpgrt_set_nonblock, gpgrt_get_nonblock, gpgrt_poll,
    gpgrt_poll_t, es_poll_t, es_set_nonblock, es_get_nonblock, es_poll,
    GPG_ERR_TRUE, GPG_ERR_FALSE, GPG_ERR_NO_NAME, GPG_ERR_NO_KEY,
    GPG_ERR_SERVER_FAILED

* Fri Sep  4 2015 Paul Howarth <paul@city-fan.org> - 1.20-1.0.cf
- Update to 1.20
  - New macros for GCC attributes
  - Make es_set_binary actually work for Windows
  - Allow building without thread support
  - Build without a build timestamp by default
  - New macros GPGRT_VERSION, GPGRT_VERSION_NUMBER, GPGRT_INLINE,
    GPGRT_GCC_VERSION, GPGRT_ATTR_NORETURN, GPGRT_ATTR_PRINTF,
    GPGRT_ATTR_NR_PRINTF, GPGRT_ATTR_FORMAT_ARG, GPGRT_ATTR_SENTINEL,
    GPGRT_ATTR_USED, GPGRT_ATTR_UNUSED, GPGRT_ATTR_DEPRECATED, GPGRT_ATTR_PURE,
    GPGRT_ATTR_MALLOC, GPGRT_HAVE_MACRO_FUNCTION and GPGRT_HAVE_PRAGMA_GCC_PUSH

* Sat Jun 20 2015 Paul Howarth <paul@city-fan.org> - 1.19-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Apr 14 2015 Paul Howarth <paul@city-fan.org> - 1.19-1.0.cf
- Update to 1.19
  - New translations for Hungarian, Portuguese, Russian, and Traditional
    Chinese
  - Updated other translations
  - New error codes: GPG_ERR_FORBIDDEN, GPG_ERR_OBJ_TERM_STATE,
    GPG_ERR_REQUEST_TOO_SHORT, GPG_ERR_REQUEST_TOO_LONG, GPG_ERR_LEGACY_KEY
  - New set of error codes for use with LDAP: GPG_ERR_LDAP_*
  - New options --help and --defines for gpg-error
  - Allow building with gcc 5

* Sat Jan 31 2015 Paul Howarth <paul@city-fan.org> - 1.17-2.0.cf
- Update to 1.17
  - New error codes for TLS protocol libraries
  - New configure option --enable-build-timestamp
  - New man page for gpg-error-config
  - Lots of new symbols - see NEWS for details
- Do not conflict on header file between architectures (#1180857)

* Sun Sep 21 2014 Paul Howarth <paul@city-fan.org> - 1.16-1.0.cf
- Update to 1.16
  - Added gpgrt_lock_trylock
  - Added the estream library under the name gpgrt and a set of macros to use
    them with their "es_" names
  - Lots of new symbols - see NEWS for details
  - Add type gpgrt_off_t, which is guaranteed to be 64 bit
  - Add type gpgrt_ssize_t to make use on Windows easier; on Unix platforms
    this is an alias for ssize_t
  - Support building for iOS
  - Fixed a prototype mismatch
  - Fix es_fclose for streams opened with "samethread"

* Mon Aug 18 2014 Paul Howarth <paul@city-fan.org> - 1.13-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jul 21 2014 Paul Howarth <paul@city-fan.org> - 1.13-2.0.cf
- Use %%license where possible

* Thu Jun 26 2014 Paul Howarth <paul@city-fan.org> - 1.13-1.0.cf
- Update to 1.13
  - Added a portable mutex API
  - The AM_PATH_GPG_ERROR macro now defines GPG_ERROR_MT_CFLAGS and
    GPG_ERROR_MT_LIBS autoconf output variables for use by programs that need
    gpgrt based thread support; gpg-error-config has a new option --mt
  - New symbols: GPG_ERR_KEY_ON_CARD, GPG_ERR_MAC_ALGO, GPG_ERR_INV_LOCK_OBJ,
    gpgrt_lock_t, GPGRT_LOCK_INITIALIZER, GPGRT_LOCK_DEFINE, gpgrt_lock_init,
    gpgrt_lock_lock, gpgrt_lock_unlock, gpgrt_lock_destroy, gpgrt_yield

* Mon Apr 28 2014 Paul Howarth <paul@city-fan.org> - 1.12-3.0.cf
- BR: hostname package rather than /bin/hostname from F-21 as the latter is no
  longer provided in rawhide
- Drop %%defattr, redundant since rpm 4.4

* Sat Aug 31 2013 Paul Howarth <paul@city-fan.org> - 1.12-1.0.cf
- Update to 1.12
  - Added support for 64-bit Windows (use ./autogen.sh --build-w64)
  - Fixed parsing and installing of the Windows .def file
  - New symbols: GPG_ERR_NO_CRYPT_CTX, GPG_ERR_WRONG_CRYPT_CTX,
    GPG_ERR_BAD_CRYPT_CTX, GPG_ERR_CRYPT_CTX_CONFLICT, GPG_ERR_BROKEN_PUBKEY,
    GPG_ERR_BROKEN_SECKEY

* Sat Aug  3 2013 Paul Howarth <paul@city-fan.org> - 1.11-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Apr  6 2013 Paul Howarth <paul@city-fan.org> - 1.11-1.0.cf
- Update to 1.11
  - New error source GPG_ERR_SOURCE_ASSUAN for Libassuan related errors
  - New macros GPG_ERROR_VERSION and GPG_ERROR_VERSION_NUMBER
  - New function gpg_error_check_version
  - New symbols: GPG_ERR_NO_KEYSERVER, GPG_ERR_INV_CURVE,
    GPG_ERR_UNKNOWN_CURVE, GPG_ERR_DUP_KEY, GPG_ERR_AMBIGUOUS,
    GPG_ERR_SOURCE_ASSUAN, gpg_error_check_version, GPG_ERROR_VERSION,
    GPG_ERROR_VERSION_NUMBER

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> - 1.10-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> - 1.10-3.0.cf
- From F-17/RHEL-7 onwards, install to %%{_libdir} rather than /%%{_lib}
  (https://fedoraproject.org/wiki/Features/UsrMove)
- Upstream ChangeLog is already UTF-8 so no need to re-code it

* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 1.10-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Jul 17 2011 Paul Howarth <paul@city-fan.org> - 1.10-1.0.cf
- Update to 1.10
  - New symbols: GPG_ERR_NOT_INITIALIZED, GPG_ERR_MISSING_ISSUER_CERT,
    GPG_ERR_FULLY_CANCELED
  - Using a static library on W32 now works
- Fix dist tag for CentOS 6 and Scientific Linux
- Nobody else likes macros for commands

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.9-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Aug 16 2010 Paul Howarth <paul@city-fan.org> - 1.9-1.0.cf
- Update to 1.9
  - New symbols: GPG_ERR_MISSING_KEY, GPG_ERR_TOO_MANY, GPG_ERR_LIMIT_REACHED
  - New function: gpg_err_deinit
  - Fix building of static lib under W32

* Mon Aug 16 2010 Paul Howarth <paul@city-fan.org> - 1.8-1.0.cf
- Update to 1.8
  - Support for WindowsCE
  - New option --list for gpg-error
  - New symbols: GPG_ERR_NOT_ENABLED, GPG_ERR_SOURCE_G13, GPG_ERR_NO_ENGINE
  - New function: gpg_err_set_errno
- BR: /bin/hostname

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.7-4.0.cf
- Fix dist tag for RHEL-6 Beta

* Fri Feb 26 2010 Paul Howarth <paul@city-fan.org> - 1.7-3.0.cf
- Turn off common lisp bindings the right way
- Build with --disable-rpath
- Drop unused finger output
- Retain timestamps where possible

* Mon Nov 16 2009 Paul Howarth <paul@city-fan.org> - 1.7-1.0.cf
- Long-overdue update to 1.7
- Dist tag for Rawhide no longer needs special-casing

* Sat Oct  3 2009 Paul Howarth <paul@city-fan.org> - 1.6-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> - 1.6-3.0.cf
- Import from Fedora
- Simplify library relocation to /%%{_lib} by using the symlinks program
- Recode ChangeLog as UTF-8
- Kill rpaths to /usr/lib64

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.6-2
- Autorebuild for GCC 4.3

* Fri Dec  7 2007 Nalin Dahyabhai <nalin@redhat.com>
- Remove the generic install docs (#226021)

* Fri Dec  7 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.6-1
- Update to 1.6
- Add suggested summary, buildrequires, and modify install call as suggested
  by package review (#226021)

* Mon Oct 15 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-6
- Use ldconfig to make the soname symlink so that it gets packaged (#331241)

* Wed Aug 22 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-5
- Add missing gawk buildrequirement

* Thu Aug 16 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-4
- Clarify license

* Mon Jul 30 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-3
- Disable static libraries (part of #249815)

* Fri Jul 27 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-2
- Move libgpg-error shared library to /%%{_lib} (#249816)

* Thu Jul 19 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-1
- Update to 1.5

* Sun Oct 01 2006 Jesse Keating <jkeating@redhat.com> - 1.4-2
- Rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Mon Sep 18 2006 Bill Nottngham <notting@redhat.com> - 1.4-1
- Update to 1.4
- Don't ship lisp bindings

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.3-3.1
- Rebuild

* Mon Jun  5 2006 Nalin Dahyabhai <nalin@redhat.com> 1.3-3
- Give gpg-error-config libdir=@exec_prefix@/lib instead of @libdir@, so that
  it agrees on 32- and 64-bit arches (it suppresses the -L argument if @libdir@
  is /usr/lib, so this should be cleaner than adding a non-standard .pc file
  which upstream developers might inadvertently think they can depend to be on
  every system which provides this library)

* Mon May 15 2006 Karsten Hopp <karsten@redhat.de> 1.3-2
- Switch to pkgconfig so that gpg-error-config can be the same on
  32bit and 64bit archs

* Tue May  2 2006 Nalin Dahyabhai <nalin@redhat.com> - 1.3-1
- Update to version 1.3

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.1-1.2.1
- Bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.1-1.2
- Rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- Rebuilt

* Wed Nov 30 2005 Karsten Hopp <karsten@redhat.de> 1.1-1
- Update

* Wed Mar  2 2005 Bill Nottingham <notting@redhat.com> - 1.0-2
- We can rebuild it - we have the technology

* Tue Aug 31 2004 Bill Nottingham <notting@redhat.com> - 1.0-1
- Update to 1.0

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Fri Apr 16 2004 Bill Nottingham <notting@redhat.com> - 0.7-1
- Adapt upstream specfile
